=======
History
=======

0.4.0 (2018-05-09)
------------------
* my.chevy website is finally back up, data structure parsing adjusted to match it

0.3.2 (2018-02-04)
------------------

* Add simple unit testing
* Stop testing on python 3.4 so we can use more advanced exceptions

0.3.1 (2018-01-31)
------------------

* Nicer error handling when server throws an error

0.3.0 (2018-01-30)
------------------

* Change data collection to use json parsing instead of screen scraping after login

0.2.0 (2018-01-21)
------------------

* Upgraded cli to use `click`

0.1.0 (2017-12-31)
------------------

* First release on PyPI.
